==> php82-nextcloud-26.0.5.tgz: share/nextcloud/apps/theming/l10n/eu.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Idatzitako izena luzeegia da",
    "The given web address is too long" : "Idatzitako web helbidea luzeegia da",
    "The given web address is not a valid URL" : "Emandako web helbidea URL baliogabea da",
    "The given legal notice address is too long" : "Emandako lege-ohar helbidea luzeegia da",
    "The given legal notice address is not a valid URL" : "Emandako lege-ohar helbidea ez da baliozko URLa",
    "The given privacy policy address is too long" : "Emandako pribatutasun-gidalerro helbidea luzeegia da",
    "The given privacy policy address is not a valid URL" : "Emandako pribatutasun-gidalerro helbidea ez da baliozko URLa",
    "The given slogan is too long" : "Emandako leloa luzeegia da",
    "The given color is invalid" : "Emandako kolorea ez du balio",
    "Disable-user-theming should be true or false" : "Desgaitu-erabiltzailea-gaiak egia ala faltsua izan behar du",
    "Saved" : "Gordeta",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Kargatutako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kargatutako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka kargatu da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategiaren karga gelditu du",
    "No file uploaded" : "Ez da fitxategirik kargatu",
    "Failed to clean up the old administration theming images folder" : "Ezin izan da garbitu administrazio zaharraren gaikako irudien karpeta",
    "Failed to clean up the old administration image folder" : "Ezin izan da garbitu administrazio zaharraren irudien karpeta ",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Gai pertsonalizatua erabiltzen ari zara dagoeneko. Gaiaren aplikazioaren ezarpenak gainidatzi ditzake.",
    "Theming" : "Itxura",
    "Appearance and accessibility" : "Itxura eta irisgarritasuna",
    "Dark theme with high contrast mode" : "Gai iluna kontraste handiko moduarekin",
    "Enable dark high contrast mode" : "Gaitu kontraste handiko modu iluna",
    "Similar to the high contrast mode, but with dark colours." : "Kontraste handiko moduaren antzekoa, baina kolore ilunekin.",
    "Dark theme" : "Gai iluna",
    "Enable dark theme" : "Gaitu gai iluna",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Gai iluna begiak arintzeko argitasuna eta distira orokorra murriztuz.",
    "System default theme" : "Sistemaren gai lehenetsia",
    "Enable the system default" : "Gaitu sistema lehenetsia",
    "Using the default system appearance." : "Sistemaren itxura lehenetsia erabiltzen.",
    "Dyslexia font" : "Dislexia letra-tipoa",
    "Enable dyslexia font" : "Gaitu dislexia letra-tipoa",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic letra-tipo librea da, dislexiak eragindako ohiko irakurketa akats batzuk leuntzeko diseinatua.",
    "High contrast mode" : "Kontraste handiko modua",
    "Enable high contrast mode" : "Gaitu kontraste handiko modua",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste handiko modua zuri nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
    "Light theme" : "Gai argia",
    "Enable the default light theme" : "Gaitu gai argi lehenetsia",
    "The default light appearance." : "Itxura argi lehenetsia.",
    "Legal notice" : "Ohar legala",
    "Privacy policy" : "Pribatutasun politika",
    "Adjust the Nextcloud theme" : "Doitu Nextcloud gaia",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Gaiak aukera ematen du zure instantziaren eta onartutako bezeroen itxura eta izaera erraz pertsonalizatzeko. Hau erabiltzaile guztientzat ikusgai egongo da.",
    "Advanced options" : "Ezarpen aurreratuak",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalatu ImageMagick PHP luzapena SVG irudietarako laguntzarekin automatikoki sortzeko igotako logotipo eta kolorean oinarritutako gogoko-ikonoak.",
    "Name" : "Izena",
    "Web link" : "Web esteka",
    "a safe home for all your data" : "zure datu guztientzako toki segurua",
    "Slogan" : "Eslogana",
    "Color" : "Kolorea",
    "Logo" : "Logoa",
    "Upload new logo" : "Kargatu logo berria",
    "Background and login image" : "Atzeko planoa eta saioa hasteko irudia",
    "Upload new background and login image" : "Kargatu atzeko planoa eta saioa hasteko irudi berria",
    "Legal notice link" : "Ohar legalaren esteka",
    "Privacy policy link" : "Pribatutasun politikaren esteka",
    "Header logo" : "Goiburuaren logoa",
    "Upload new header logo" : "Kargatu goiburuaren logo berria",
    "Favicon" : "Gogoko-ikonoa",
    "Upload new favicon" : "Kargatu gogoko-ikono berria",
    "User settings" : "Erabiltzaile ezarpenak",
    "Disable user theming" : "Desgaitu erabiltzaile itxura",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Zure instantzia hautatu eta pertsonaliza dezakezun arren, erabiltzaileek atzeko planoa eta koloreak alda ditzakete. Zure pertsonalizazioa aplikatu nahi baduzu, hau aktibatu dezakezu.",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Zenbait kasutan, teklatuko lasterbideek erabilerraztasun-tresnekin oztopatu dezakete. Zure tresna behar bezala zentratu ahal izateko, hemen teklatuko lasterbide guztiak desgaitu ditzakezu. Honek aplikazioetan erabilgarri dauden lasterbide guztiak ere desgaituko ditu.",
    "Disable all keyboard shortcuts" : "Desgaitu teklatuaren lasterbide guztiak",
    "Background" : "Atzeko planoa",
    "Customization has been disabled by your administrator" : "Zure administratzaileak pertsonalizazioa desgaitu du",
    "Set a custom background" : "Ezarri atzeko planoko irudi pertsonalizatua",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Sarbide unibertsala izatea oso garrantzitsua da guretzat. Web estadandarrak jarraitu eta guztia sagurik gabe erabili ahal izatea bermatzen dugu, pantaila-irakurle moduko software laguntzaileak barne. Helburu bezala jartzen dugu {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 AA mailan betetzea, kontraste altuko modua AAA mailaraino betez.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Arazoren bat aurkitzen baduzu, ez izan zalantzarik eta jakinarazi {issuetracker}gure arazoen jarraipena{linkend} zerbitzuan. Eta parte hartu nahi baduzu, etorri {designteam}gure diseinu taldera{linkend}!",
    "Custom background" : "Atzeko plano pertsonalizatua",
    "Default background" : "Atzeko plano lehenetsia",
    "Change color" : "Aldatu kolorea",
    "No background" : "atzeko planorik ez",
    "Select a background from your files" : "Hautatu atzeko plano bat zure fitxategietatik",
    "Theme selection is enforced" : "Gaiaren hautaketa behartuta dago",
    "Select a custom color" : "Hautatu kolore pertsonalizatu bat",
    "Reset to default" : "Berezarri balio lehenetsira",
    "Upload" : "Kargatu",
    "Remove background image" : "Kendu atzeko-planoko irudia",
    "Loading preview…" : "Aurreikuspena kargatzen...",
    "Admin" : "Administratzailea",
    "Error uploading the file" : "Errorea fitxategia igotzen",
    "Name cannot be empty" : "Izena ezin da hutsik egon",
    "Migrate and clean up admin theming images" : "Migratu eta garbitu administratzaile gaiaren irudiak",
    "Failed to clean up the old admin theming images folder" : "Ezin izan da garbitu administratzailearen gaiaren irudien karpeta zaharra",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Zenbait kasutan, teklatuko lasterbideek erabilerraztasun-tresnekin oztopatu dezakete. Zure tresna behar bezala zentratu ahal izateko, hemen teklatuko lasterbide guztiak desgaitu ditzakezu. Honek aplikazioetan erabilgarri dauden lasterbide guztiak ere desgaituko ditu.",
    "Pick from Files" : "Hautatu fitxategietatik",
    "Default image" : "Irudi lehenetsia",
    "Custom color" : "Kolore pertsonalizatua",
    "Plain background" : "Atzeko plano arrunta",
    "Insert from {productName}" : "Txertatu hemendik: {productName}",
    "Open documentation" : "Ireki dokumentazioa",
    "https://…" : "https://…",
    "Upload new login background" : "Kargatu saio-hasiera atzeko-plano berria",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Zure instantzia hautatu eta pertsonaliza dezakezun arren, erabiltzaileek atzeko planoa eta koloreak alda ditzakete. Zure pertsonalizazioa aplikatu nahi baduzu, lauki hau markatu dezakezu.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalatu Imagemagick PHP luzapena SVG irudien laguntzarekin igotako logotipoan eta kolorean oinarritutako gogoko-ikonoak automatikoki sortzeko."
},
"nplurals=2; plural=(n != 1);");

==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/theming/l10n/eu.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Idatzitako izena luzeegia da",
    "The given web address is too long" : "Idatzitako web helbidea luzeegia da",
    "The given web address is not a valid URL" : "Emandako web helbidea URL baliogabea da",
    "The given legal notice address is too long" : "Emandako lege-ohar helbidea luzeegia da",
    "The given legal notice address is not a valid URL" : "Emandako lege-ohar helbidea ez da baliozko URLa",
    "The given privacy policy address is too long" : "Emandako pribatutasun-gidalerro helbidea luzeegia da",
    "The given privacy policy address is not a valid URL" : "Emandako pribatutasun-gidalerro helbidea ez da baliozko URLa",
    "The given slogan is too long" : "Emandako leloa luzeegia da",
    "The given color is invalid" : "Emandako kolorea ez du balio",
    "Disable-user-theming should be true or false" : "Desgaitu-erabiltzailea-gaiak egia ala faltsua izan behar du",
    "Saved" : "Gordeta",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Igotako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Igotako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka igo da",
    "No file was uploaded" : "Ez da fitxategirik igo",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategiaren igoera gelditu du",
    "No file uploaded" : "Ez da fitxategirik igo",
    "Failed to clean up the old administration theming images folder" : "Ezin izan da garbitu administrazio zaharraren gaikako irudien karpeta",
    "Failed to clean up the old administration image folder" : "Ezin izan da garbitu administrazio zaharraren irudien karpeta ",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Gai pertsonalizatua erabiltzen ari zara dagoeneko. Gaiaren aplikazioaren ezarpenak gainidatzi ditzake.",
    "Theming" : "Itxura",
    "Appearance and accessibility" : "Itxura eta irisgarritasuna",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "\"Imagick\" PHP modulua  ez dago gaituta, nahiz eta gaiak pertsonalizatzeko aplikazioa badagoen. Faviconen sorrerak behar bezala funtziona dezan, modulu hau instalatu eta gaitu behar duzu.",
    "Dark theme with high contrast mode" : "Gai iluna kontraste handiko moduarekin",
    "Enable dark high contrast mode" : "Gaitu kontraste handiko modu iluna",
    "Similar to the high contrast mode, but with dark colours." : "Kontraste handiko moduaren antzekoa, baina kolore ilunekin.",
    "Dark theme" : "Gai iluna",
    "Enable dark theme" : "Gaitu gai iluna",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Gai iluna begiak arintzeko argitasuna eta distira orokorra murriztuz.",
    "System default theme" : "Sistemaren gai lehenetsia",
    "Enable the system default" : "Gaitu sistema lehenetsia",
    "Using the default system appearance." : "Sistemaren itxura lehenetsia erabiltzen.",
    "Dyslexia font" : "Dislexia letra-tipoa",
    "Enable dyslexia font" : "Gaitu dislexia letra-tipoa",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic letra-tipo librea da, dislexiak eragindako ohiko irakurketa akats batzuk leuntzeko diseinatua.",
    "High contrast mode" : "Kontraste handiko modua",
    "Enable high contrast mode" : "Gaitu kontraste handiko modua",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kontraste handiko modua zuri nabigazioa errazteko. Kalitate bisuala murriztuko da baina argitasuna handiagotu.",
    "Light theme" : "Gai argia",
    "Enable the default light theme" : "Gaitu gai argi lehenetsia",
    "The default light appearance." : "Itxura argi lehenetsia.",
    "Legal notice" : "Ohar legala",
    "Privacy policy" : "Pribatutasun politika",
    "Adjust the Nextcloud theme" : "Doitu Nextcloud gaia",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Gaiak aukera ematen du zure instantziaren eta onartutako bezeroen itxura eta izaera erraz pertsonalizatzeko. Hau erabiltzaile guztientzat ikusgai egongo da.",
    "Advanced options" : "Ezarpen aurreratuak",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalatu ImageMagick PHP luzapena SVG irudietarako laguntzarekin automatikoki sortzeko igotako logotipo eta kolorean oinarritutako gogoko-ikonoak.",
    "Name" : "Izena",
    "Web link" : "Web esteka",
    "a safe home for all your data" : "zure datu guztientzako toki segurua",
    "Slogan" : "Eslogana",
    "Color" : "Kolorea",
    "Logo" : "Logoa",
    "Upload new logo" : "Igo logo berria",
    "Background and login image" : "Atzeko planoa eta saioa hasteko irudia",
    "Upload new background and login image" : "Igo atzeko planoa eta saioa hasteko irudi berria",
    "Legal notice link" : "Ohar legalaren esteka",
    "Privacy policy link" : "Pribatutasun politikaren esteka",
    "Header logo" : "Goiburuaren logoa",
    "Upload new header logo" : "Igo goiburuaren logo berria",
    "Favicon" : "Gogoko-ikonoa",
    "Upload new favicon" : "Igo gogoko-ikono berria",
    "User settings" : "Erabiltzaile ezarpenak",
    "Disable user theming" : "Desgaitu erabiltzaile itxura",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Zure instantzia hautatu eta pertsonaliza dezakezun arren, erabiltzaileek atzeko planoa eta koloreak alda ditzakete. Zure pertsonalizazioa aplikatu nahi baduzu, hau aktibatu dezakezu.",
    "Background" : "Atzeko planoa",
    "Customization has been disabled by your administrator" : "Zure administratzaileak pertsonalizazioa desgaitu du",
    "Set a custom background" : "Ezarri atzeko planoko irudi pertsonalizatua",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Zenbait kasutan, teklatuko lasterbideek erabilerraztasun-tresnekin oztopatu dezakete. Zure tresna behar bezala zentratu ahal izateko, hemen teklatuko lasterbide guztiak desgaitu ditzakezu. Honek aplikazioetan erabilgarri dauden lasterbide guztiak ere desgaituko ditu.",
    "Disable all keyboard shortcuts" : "Desgaitu teklatuaren lasterbide guztiak",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Sarbide unibertsala izatea oso garrantzitsua da guretzat. Web estadandarrak jarraitu eta guztia sagurik gabe erabili ahal izatea bermatzen dugu, pantaila-irakurle moduko software laguntzaileak barne. Helburu bezala jartzen dugu {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 AA mailan betetzea, kontraste altuko modua AAA mailaraino betez.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Arazoren bat aurkitzen baduzu, ez izan zalantzarik eta jakinarazi {issuetracker}gure arazoen jarraipena{linkend} zerbitzuan. Eta parte hartu nahi baduzu, etorri {designteam}gure diseinu taldera{linkend}!",
    "Move up" : "Eraman gora",
    "Move down" : "Eraman behera",
    "Custom background" : "Atzeko plano pertsonalizatua",
    "Default background" : "Atzeko plano lehenetsia",
    "Change color" : "Aldatu kolorea",
    "No background" : "atzeko planorik ez",
    "Select a background from your files" : "Hautatu atzeko plano bat zure fitxategietatik",
    "Select background" : "Hautatu atzeko planoa",
    "No background has been selected" : "Ez da atzeko planorik hautatu",
    "Theme selection is enforced" : "Gaiaren hautaketa behartuta dago",
    "Reset to default" : "Berezarri balio lehenetsira",
    "Upload" : "Igo",
    "Remove background image" : "Kendu atzeko-planoko irudia",
    "Select a custom color" : "Hautatu kolore pertsonalizatu bat"
},
"nplurals=2; plural=(n != 1);");
